% Created by: R.Holser (rholser@ucsc.edu 
% Created on: 14-Aug-2023
%
% Combine MetaDataAll and TagMetaDataAll, only keep columns relevent to netCDF files, rename columns
% to match global attributes, and save as csv

clear
load("D:\Dropbox\MATLAB\Projects\Eseal Data Processing - MatFiles\MetaData.mat")
load("MetaData.mat")

%Create empty table to populate that matches length of MetaDataAll
ToAdd=table('Size',[size(MetaDataAll,1),size(TagMetaDataAll,2)],'VariableTypes',varfun(@class,TagMetaDataAll,'OutputFormat','cell'), ...
    'VariableNames',TagMetaDataAll.Properties.VariableNames);

%Find TagMetaDataAll row that matches each TOPPID and add to new table, if no tag metadata, leave row blank
for i=1:size(MetaDataAll)
    try
        ToAdd(i,:)=TagMetaDataAll(TagMetaDataAll.TOPPID==MetaDataAll.TOPPID(i),:);
    end
end

% Only keep needed columns of MetaDataAll
MetaDataAll=MetaDataAll(:,ismember(MetaDataAll.Properties.VariableNames, {'DepartDate','ArriveDate',...
    'DepartLat','DepartLon','ArriveLat','ArriveLon','DepartLoc','ArriveLoc','Season','BirthYear','AgeClass', ...
    'Sex','Manipulation','ManipulationType','HadPup','Comment'}));
%Concatenate tables
MetaDataAll=[ToAdd MetaDataAll];
%Remove rows pre-2004 and unneeded columns from TagMetaData
%MetaDataAll(1:15,:)=[];
MetaDataAll(:,27:35)=[];
%Add column for year
MetaDataAll.Year=year(MetaDataAll.DepartDate);
%List of new names that match netCDF global attributes
NewNames={'Animal_ID','Deployment_ID','Tags_SatTag_Manufacturer','Tags_SatTag_Model','Tags_SatTag_ID','Tags_PTT',...
    'Data_Track_QCFlag','Tags_SatTag_Comments','Tags_TDR1_Manufacturer','Tags_TDR1_Model','Tags_TDR1_ID','Tags_TDR1_Loc'...
    'Data_TDR1_QCFlag','Tags_TDR1_Comments','Tags_TDR2_Manufacturer','Tags_TDR2_Model','Tags_TDR2_ID','Tags_TDR2_Loc'...
    'Data_TDR2_QCFlag','Tags_TDR2_Comments','Tags_TDR3_Manufacturer','Tags_TDR3_Model','Tags_TDR3_ID','Tags_TDR3_Loc'...
    'Data_TDR3_QCFlag','Tags_TDR3_Comments','Data_TDR1_DepthResolution_m','Data_TDR1_SamplingFrequency_Hz',...
    'Data_TDR2_DepthResolution_m','Data_TDR2_SamplingFrequency_Hz','Data_TDR3_DepthResolution_m','Data_TDR3_SamplingFrequency_Hz',...
    'Deployment_Departure_Datetime','Deployment_Arrival_Datetime','Deployment_Departure_Lat','Deployment_Departure_Lon',...
    'Deployment_Arrival_Lat','Deployment_Arrival_Lon','Deployment_Departure_Loc','Deployment_Arrival_Loc','Deployment_Trip',...
    'Animal_BirthYear','Animal_AgeClass','Animal_Sex','Deployment_Manipulation','Deployment_ManipulationType',...
    'Animal_HadPup','Deployment_Year'};
%Rename variables and export to csv
MetaDataAll=renamevars(MetaDataAll,MetaDataAll.Properties.VariableNames,NewNames);
writetable(MetaDataAll,'NES_TrackingDiving_MetaData.csv')